@@ -1,6 +1,7 @@
 """
 A few toys the API will use.
 """
+import six
 import time
 from functools import wraps
 
@@ -8,6 +9,7 @@ from functools import wraps
 # Exceptions
 #
 
+
 class CredentialsMissingError(Exception):
     """
     Raised if an API call is attempted without the required login credentials
@@ -28,6 +30,7 @@ class DoesNotExistError(Exception):
     """
     pass
 
+
 class DuplicateObjectError(Exception):
     """
     Raised when the user tries to add a duplicate to a distinct list.
@@ -38,25 +41,28 @@ class DuplicateObjectError(Exception):
 # Decorators
 #
 
+
 def credentials_required(method_func):
     """
     Decorator for methods that checks that the client has credentials.
-    
+
     Throws a CredentialsMissingError when they are absent.
     """
     def _checkcredentials(self, *args, **kwargs):
         if self.username and self.password:
             return method_func(self, *args, **kwargs)
         else:
-            raise CredentialsMissingError("This is a private method. You must provide a username and password when you initialize the DocumentCloud client to attempt this type of request.")
-    
+            raise CredentialsMissingError("This is a private method. \
+You must provide a username and password when you initialize the \
+DocumentCloud client to attempt this type of request.")
+
     return wraps(method_func)(_checkcredentials)
 
 
-def retry(ExceptionToCheck, tries=4, delay=3, backoff=2):
+def retry(ExceptionToCheck, tries=3, delay=2, backoff=2):
     """
-    Retry decorator published by Saltry Crane. 
-    
+    Retry decorator published by Saltry Crane.
+
     http://www.saltycrane.com/blog/2009/11/trying-out-retry-decorator-python/
     """
     def deco_retry(f):
@@ -68,13 +74,13 @@ def retry(ExceptionToCheck, tries=4, delay=3, backoff=2):
                     return f(*args, **kwargs)
                     try_one_last_time = False
                     break
-                except ExceptionToCheck, e:
+                except ExceptionToCheck:
+                    six.print_("Retrying in %s seconds" % str(mdelay))
                     time.sleep(mdelay)
                     mtries -= 1
                     mdelay *= backoff
             if try_one_last_time:
                 return f(*args, **kwargs)
             return
-        return f_retry # true decorator
+        return f_retry  # true decorator
     return deco_retry
-
